@@ -368,18 +368,9 @@ class XMLRPCCommand(Command):
 
     def _check_server_version(self, server_obj, required_version):
         """
-        Check that server object has is at least required_version.
-
-        This method may raise InsufficientServerVersion.
+        Obsolete function dating from pre-packaging requirements
         """
-        from distutils.version import StrictVersion, LooseVersion
-        # For backwards compatibility the server reports
-        # major.minor.micro.releaselevel.serial which is not PEP-386 compliant
-        server_version = StrictVersion(
-            self._strict_server_version(server_obj.version()))
-        required_version = StrictVersion(required_version)
-        if server_version < required_version:
-            raise InsufficientServerVersion(server_version, required_version)
+        return True
 
     def __init__(self, parser, args):
         super(XMLRPCCommand, self).__init__(parser, args)
@@ -465,11 +456,11 @@ class XMLRPCCommand(Command):
 class server_version(XMLRPCCommand):
 
     """
-    Display dashboard server version
+    Display LAVA server version
     """
 
     def invoke_remote(self):
-        print "Dashboard server version: %s" % (self.server.version(),)
+        print "LAVA server version: %s" % (self.server.version(),)
 
 
 class put(XMLRPCCommand):
